@@ -858,6 +858,8 @@ parser_step_headers (GMimeParser *parser)
 			if (inptr == inend) {
 				/* we don't have enough data to tell if we
 				   got all of the header or not... */
+				header_append (priv, start, inptr - start);
+				priv->midline = TRUE;
 				priv->inptr = inptr;
 				len = inend - inptr;
 				goto refill;
@@ -873,19 +875,16 @@ parser_step_headers (GMimeParser *parser)
 			
 			header_append (priv, start, len);
 			
-			if (inptr < inend) {
-				/* inptr has to be less than inend - 1 */
-				raw_header_append (priv, inptr, 1);
-				inptr++;
-				if (*inptr == ' ' || *inptr == '\t') {
-					priv->midline = TRUE;
-				} else {
-					priv->midline = FALSE;
-					header_parse (parser, priv, hend);
-					priv->header_start = parser_offset (priv, inptr);
-				}
-			} else {
+			/* inptr has to be less than inend - 1 */
+			raw_header_append (priv, inptr, 1);
+			inptr++;
+			
+			if (*inptr == ' ' || *inptr == '\t') {
 				priv->midline = TRUE;
+			} else {
+				priv->midline = FALSE;
+				header_parse (parser, priv, hend);
+				priv->header_start = parser_offset (priv, inptr);
 			}
 		}
 		
@@ -897,6 +896,7 @@ parser_step_headers (GMimeParser *parser)
 	inend = priv->inend;
 	
 	header_append (priv, inptr, inend - inptr);
+	raw_header_append (priv, inptr, inend - inptr);
 	
  headers_end:
 	
